@@ -3,7 +3,7 @@ Field mapping between Wildlife Insights and the Darwin Core standard.
 """
 events = {
     "deployment_id": "eventID",
-    "project_id": "parentEventID",
+    "placename": "parentEventID",
     "event_name": "eventRemarks",
     "feature_type": "locationRemarks",
     "latitude": "decimalLatitude",
@@ -11,7 +11,7 @@ events = {
 }
 
 records = {
-    "project_id": "parentEventID",
+    "placename": "parentEventID",
     "deployment_id": "eventID",
     "individual_animal_notes": "occurrenceRemarks",
     "image_id": "recordNumber",
